Available on crate feature
estimation only.Expand description
Parameter estimation methods for copulas.
This module provides various methods for estimating copula parameters from data:
- Maximum Likelihood Estimation (MLE)
- Inference Functions for Margins (IFM)
- Canonical Maximum Likelihood (CML)
- Method of Moments
Overview
Maximum Likelihood (MLE)
Estimates both marginal and copula parameters jointly by maximizing: L(θ) = Σ log c(F₁(x₁|θ₁), …, Fₐ(xₐ|θₐ)|θ_c)
Inference Functions for Margins (IFM)
Two-stage estimation:
- Estimate marginal parameters
- Estimate copula parameters given marginals
Canonical Maximum Likelihood (CML)
Uses empirical CDFs for margins, estimates only copula parameters.
Bibliography
- Joe, H. (2005). Asymptotic efficiency of the two-stage estimation method for copula-based models.
- Genest, C., et al. (1995). A semiparametric estimation procedure of dependence parameters in multivariate families of distributions.
Structs
- CMLEstimator
- Canonical Maximum Likelihood (CML) estimator.
- Empirical
Cdf - Empirical CDF estimator.
- TauEstimator
- Method of moments estimator using Kendall’s tau.
Functions
- kendall_
tau - Estimate Kendall’s tau from data.
- spearman_
rho - Estimate Spearman’s rho from data.
- to_
pseudo_ observations - Convert multivariate data to pseudo-observations (uniform margins).